A_DOIP_CTRL = 2  # 2s
A_DOIP_ACCOUNCE_MAX_WAIT = 0.500  # 0..500ms
A_DOIP_ANNOUNCE_INTERVAL = 0.500  # 500ms
A_DOIP_ANNOUNCE_NUM = 3  # 3 times
A_DOIP_DIAGNOSTIC_MESSAGE = 2  # 2s
T_TCP_GENERAL_INACTIVITY = 300  # 5 Min
T_TCP_INITIAL_INACTIVITY = 2  # 2s
T_TCP_ALIVE_CHECK = 0.500  # 500ms
A_PROCESSING_TIME = 2  # 2s
A_VEHICLE_DISCOVERY_TIMER = 5  # 5s

# Table 41 - UDP ports
UDP_DISCOVERY = 13400

# Table 39 - Supported TCP ports
TCP_DATA_UNSECURED = 13400
TCP_DATA_SECURED = 3496

# link-local scope multicast address (FF02 16 ::1) 
LINK_LOCAL_MULTICAST_ADDRESS = "ff02::1"